<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Management.Deployment.Preview

Windows Runtime (WinRT) APIs for for the `Windows.Management.Deployment.Preview` namespace.

This package provides the `winrt.windows.management.deployment.preview` module.
